==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2305_171.zip: ronportal/ron/http/htmlheaders.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 18.09.2015
 */

namespace Ron\Http;

use Ron\GuiUtils;

class HtmlHeaders
{
    /** @var string[] */
    protected $headers = [];

    /** @var string[] */
    protected $bodyAttributes = [];

    /** @var string   Pripojuje se za jmeno souboru (css, script) pro zabraneni cachovani */
    public $versionId;

    private static $htmlHeaders;


    public function __construct($versionId = null)
    {
        $this ->versionId = $versionId;
    }


    /**
     * Vraci globalni instanci objektu HtmlHeaders
     * @return HtmlHeaders
     */
    public static function getInstance()
    {
        if (!self::$htmlHeaders) {
            self::$htmlHeaders = new HtmlHeaders();
        };

        return self::$htmlHeaders;
    }


    /**
     * Prida radek do HTML head.
     * @param string $header
     * @param string $id        Pokud je zadan $id a uz existuje radek se stejnym $id, tak jej nahradi
     * @return HtmlHeaders      Vraci $this pro moznost zretezeni
     */
    public function addHeader($header, $id = null)
    {
        if ($id) {
            $this->headers[$id] = $header;
        } else {
            $this->headers[] = $header;
        }

        return $this;
    }


    public function addCss($filename, $id = null, $params = '')
    {
        if (!$params  &&  $this ->versionId) {
            $params = '?ver=' . $this ->versionId;
        }

        $this ->addHeader(
            '<link rel="stylesheet" type="text/css" href="' .
            $filename . $params .
            '" nonce="' . HttpHeaders::getNonce() . '">',
            $id
        );

        return $this;
    }


    /**
     * Prida do HTML hlavicky zadany skript.
     * @param string $filename
     * @param string $id        viz {@see HtmlHeaders::addHeader}
     * @param string $params    Parametry, ktere se pridaji k url. Pokud nejsou zadany, tak se automaticky prida parametr ver=...
     * @return HtmlHeaders      Vraci $this pro moznost zretezeni
     */
    public function addScript($filename, $id = null, $params = '')
    {
        if (!$params  &&  $id  &&  $id[0] === '?') {
            // pro kompatibilitu se starym kodem (puvodne bylo $params druhy parametr a $id treti)
            $params = $id;
            $id = null;
        }

        if (!$params  &&  $this ->versionId) {
            $params = '?ver=' . $this ->versionId;
        }

        $this ->addHeader(
            '<script type="text/javascript" src="' .
            $filename . $params .
            '" nonce="' . HttpHeaders::getNonce() . '"></script>',
            $id
        );

        return $this;
    }


    public function setTitle($title)
    {
        $this ->addHeader("<title>$title</title>", 'title');
        return $this;
    }


    /**
     * Nastavi ikonu zobrazovanou v prohlizeci
     * @param $iconFile
     * @return $this
     */
    public function setIcon($iconFile)
    {
        $this ->addHeader("<link rel='shortcut icon' sizes='16x16' type='image/png' href='$iconFile'>", 'shortcut_icon');
        //$this ->addHeader("<link rel='apple-touch-icon' sizes='180x180' href='images/D_180x180.png'>", 'shortcut_icon_180'); - toto by bylo potreba, aby se zobrazovala i na plose Androidu
        return $this;
    }


    public function render()
    {
        foreach ($this ->headers as $header) {
            echo $header . "\n";
        }

        if (isset($this ->title)) {
            echo "<title>" . $this ->title . "</title>";
        }
    }


    /**
     * Prida atribut, ktery se vyrendruje u tagu <body> v html strance
     * @param string $name  Jmeno atributu
     * @param string $value Hodnota atributu
     * @return $this
     */
    public function addBodyAttribute($name, $value)
    {
        $this ->bodyAttributes[$name] = $value;
        return $this;
    }


    public function getBodyAttributesHtml()
    {
        return GuiUtils::getAttributesHtml($this ->bodyAttributes);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ron/http/htmlheaders.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 18.09.2015
 */

namespace Ron\Http;

use Ron\GuiUtils;

/**
 * Zajistuje spravu hlavicek HTML stranky (tech, ktere patri do tagu <head>) - udrzuje jejich seznam, umoznuje jejich pridavani a zmenu. Zajistuje renderovani hlavicek.
 */
class HtmlHeaders
{
    /** @var string[]   Seznam HTML hlavicek */
    protected $headers = [];

    /** @var string[]   Atributy, ktere se maji pridat k tagu <body> v HTML strance */
    protected $bodyAttributes = [];

    /** @var string     Pripojuje se za jmeno souboru (css, script) pro zabraneni cachovani */
    public $versionId;

    /** @var string     Titulek aplikace - pouzije se v metode setAppTitle */
    public $originalTitle;

    /** @var HtmlHeaders    Globalni instance */
    private static $htmlHeaders;


    public function __construct($versionId = null)
    {
        $this ->versionId = $versionId;
    }


    /**
     * Vraci globalni instanci objektu HtmlHeaders
     * @return HtmlHeaders
     */
    public static function getInstance()
    {
        if (!self::$htmlHeaders) {
            self::$htmlHeaders = new HtmlHeaders();
        };

        return self::$htmlHeaders;
    }


    /**
     * Prida zadanou hlavicku do seznamu hlavicek.
     * @param string $header
     * @param string $id        Pokud je zadan $id a uz existuje radek se stejnym $id, tak jej nahradi
     * @return HtmlHeaders      Vraci $this pro moznost zretezeni
     */
    public function addHeader($header, $id = null)
    {
        if ($id) {
            $this->headers[$id] = $header;
        } else {
            $this->headers[] = $header;
        }

        return $this;
    }


    /**
     * Prida hlavicku pro nacteni zadaneho CSS souboru (<link rel="stylesheet" ... >
     * @param string $filename  Jmeno CSS souboru - relativni vzhledem ke strance pozadovane prohlizecem, nebo absolutni
     * @param ?string $id       Id - pokud jiz existuje hlavicka se zadanym id, tak ji prepise
     * @param ?string $params   Parametry pro sestavni URL adresy - pokud nejsou zadany, tak se pridava implicitni parametr s cislem verze $versionId
     * @return $this
     */
    public function addCss($filename, $id = null, $params = '')
    {
        if (!$params  &&  $this ->versionId) {
            $params = '?ver=' . $this ->versionId;
        }

        $this ->addHeader(
            '<link rel="stylesheet" type="text/css" href="' .
            $filename . $params .
            '" nonce="' . HttpHeaders::getNonce() . '">',
            $id
        );

        return $this;
    }


    /**
     * Prida do HTML hlavicky zadany skript.
     * @param string $filename  Jmeno souboru se skriptem
     * @param string $id        viz {@see HtmlHeaders::addHeader}
     * @param string $params    Parametry, ktere se pridaji k url. Pokud nejsou zadany, tak se automaticky prida parametr ver=$versionId
     * @return HtmlHeaders      Vraci $this pro moznost zretezeni
     */
    public function addScript($filename, $id = null, $params = '')
    {
        if (!$params  &&  $id  &&  $id[0] === '?') {
            // pro kompatibilitu se starym kodem (puvodne bylo $params druhy parametr a $id treti)
            $params = $id;
            $id = null;
        }

        if (!$params  &&  $this ->versionId) {
            $params = '?ver=' . $this ->versionId;
        }

        $this ->addHeader(
            '<script type="text/javascript" src="' .
            $filename . $params .
            '" nonce="' . HttpHeaders::getNonce() . '"></script>',
            $id
        );

        return $this;
    }


    /**
     * Nastavi title HTML stranky
     * @param string $title
     * @return $this
     */
    public function setTitle($title)
    {
        $this ->addHeader("<title>$title</title>", 'title');
        return $this;
    }


    /**
     * Nastavi title HTML stranky. Pokud je nastavena promenna
     * @param $title
     * @return $this
     */
    public function setAppTitle($title)
    {
        $this ->setTitle(($this ->originalTitle ? $this ->originalTitle . ' - ' : '') . $title);
        return $this;
    }

    /**
     * Nastavi ikonu zobrazovanou v prohlizeci
     * @param string $iconFile
     * @return $this
     */
    public function setIcon($iconFile)
    {
        $this ->addHeader("<link rel='shortcut icon' sizes='16x16' type='image/png' href='$iconFile'>", 'shortcut_icon');
        //$this ->addHeader("<link rel='apple-touch-icon' sizes='180x180' href='images/D_180x180.png'>", 'shortcut_icon_180'); - toto by bylo potreba, aby se zobrazovala i na plose Androidu
        return $this;
    }


    /**
     * Renderuje HTML hlavicky
     * @return void
     */
    public function render()
    {
        foreach ($this ->headers as $header) {
            echo $header . "\n";
        }

        if (isset($this ->title)) {
            echo "<title>" . $this ->title . "</title>";
        }
    }


    /**
     * Prida atribut, ktery se vyrenderuje u tagu <body> v html strance
     * @param string $name  Jmeno atributu
     * @param string $value Hodnota atributu
     * @return $this
     */
    public function addBodyAttribute($name, $value)
    {
        $this ->bodyAttributes[$name] = $value;
        return $this;
    }


    /**
     * Vraci HTML atributy pro tag <body> jako text
     * @return string
     */
    public function getBodyAttributesHtml()
    {
        return GuiUtils::getAttributesHtml($this ->bodyAttributes);
    }
}
